@@ -21,9 +21,22 @@ class FarOpt(object):
                 logging.info('FarOpt backend is ready!')
                 self.ready = True
                 self.stackname = stackname
-                self.bucket = response['Stacks'][0]['Outputs'][0]['OutputValue'] # S3 bucket
-                self.jobtable = response['Stacks'][0]['Outputs'][2]['OutputValue'] # DynamoDB table for jobs
-                self.recipetable = response['Stacks'][0]['Outputs'][1]['OutputValue'] # DynamoDB table for recipes
+                # self.bucket = response['Stacks'][0]['Outputs'][1]['OutputValue'] # S3 bucket
+                # self.jobtable = response['Stacks'][0]['Outputs'][3]['OutputValue'] # DynamoDB table for jobs
+                # self.recipetable = response['Stacks'][0]['Outputs'][2]['OutputValue'] # DynamoDB table for recipes
+                # self.recipetable = response['Stacks'][0]['Outputs'][0]['OutputValue'] # S3 async bucket
+                
+                outputs = response['Stacks'][0]['Outputs']
+                for output in outputs:
+                    if output['OutputKey']=='s3asyncoutput':
+                        self.asyncbucket = output['OutputValue']
+                    elif output['OutputKey']=='s3output':
+                        self.bucket = output['OutputValue']
+                    elif output['OutputKey']=='recipetable':
+                        self.recipetable = output['OutputValue']
+                    elif output['OutputKey']=='jobtable':
+                        self.jobtable = output['OutputValue']
+                
                 self.configured = False
                 self.submitted = False
         except Exception as e:
